==> bonita-server-6.5.3-sources.jar: sql/postgres/deleteTenantObjects.sql <==
DELETE FROM actormember WHERE tenantid = ${tenantid};
DELETE FROM actor WHERE tenantid = ${tenantid};
DELETE FROM processcategorymapping WHERE tenantid = ${tenantid};
DELETE FROM category WHERE tenantid = ${tenantid};
DELETE FROM arch_process_comment WHERE tenantid = ${tenantid};
DELETE FROM process_comment WHERE tenantid = ${tenantid};
DELETE FROM process_definition WHERE tenantid = ${tenantid};
DELETE FROM arch_document_mapping WHERE tenantid = ${tenantid};
DELETE FROM document WHERE tenantid = ${tenantid};
DELETE FROM document_mapping WHERE tenantid = ${tenantid};
DELETE FROM arch_flownode_instance WHERE tenantid = ${tenantid};
DELETE FROM arch_process_instance WHERE tenantid = ${tenantid};
DELETE FROM arch_transition_instance  WHERE tenantid = ${tenantid};
DELETE FROM arch_connector_instance  WHERE tenantid = ${tenantid};
DELETE FROM multi_biz_data WHERE tenantid = ${tenantid};
DELETE FROM ref_biz_data_inst WHERE tenantid = ${tenantid};
DELETE FROM connector_instance WHERE tenantid = ${tenantid};
DELETE FROM message_instance WHERE tenantid = ${tenantid};
DELETE FROM pending_mapping WHERE tenantid = ${tenantid};
DELETE FROM event_trigger_instance WHERE tenantid = ${tenantid};
DELETE FROM waiting_event WHERE tenantid = ${tenantid};
DELETE FROM process_instance WHERE tenantid = ${tenantid};
DELETE FROM flownode_instance WHERE tenantid = ${tenantid};
DELETE FROM breakpoint WHERE tenantid = ${tenantid};
DELETE FROM report WHERE tenantid = ${tenantid};
DELETE FROM processsupervisor WHERE tenantid = ${tenantid};
DELETE FROM business_app WHERE tenantid = ${tenantid};
DELETE FROM business_app_page WHERE tenantid = ${tenantid};
DELETE FROM business_app_menu WHERE tenantid = ${tenantid};
DELETE FROM command WHERE tenantid = ${tenantid};
DELETE FROM arch_data_instance WHERE tenantid = ${tenantid};
DELETE FROM data_instance WHERE tenantid = ${tenantid};
DELETE FROM dependencymapping WHERE tenantid = ${tenantid};
DELETE FROM dependency WHERE tenantid = ${tenantid};
DELETE FROM external_identity_mapping WHERE tenantid = ${tenantid};
DELETE FROM user_membership WHERE tenantid = ${tenantid};
DELETE FROM custom_usr_inf_val WHERE tenantid = ${tenantid};
DELETE FROM custom_usr_inf_def WHERE tenantid = ${tenantid};
DELETE FROM user_login WHERE tenantid = ${tenantid};
DELETE FROM user_ WHERE tenantid = ${tenantid};
DELETE FROM user_contactinfo WHERE tenantid = ${tenantid};
DELETE FROM role WHERE tenantid = ${tenantid};
DELETE FROM group_ WHERE tenantid = ${tenantid};
DELETE FROM queriablelog_p WHERE tenantid = ${tenantid};
DELETE FROM queriable_log WHERE tenantid = ${tenantid};
DELETE FROM page WHERE tenantid = ${tenantid};
DELETE FROM sequence WHERE tenantid = ${tenantid};
DELETE FROM profilemember WHERE tenantid = ${tenantid};
DELETE FROM profileentry WHERE tenantid = ${tenantid};
DELETE FROM profile WHERE tenantid = ${tenantid};
DELETE FROM job_log WHERE tenantid = ${tenantid};
DELETE FROM job_param WHERE tenantid = ${tenantid};
DELETE FROM job_desc WHERE tenantid = ${tenantid};
DELETE FROM theme WHERE tenantid = ${tenantid};

==> bonita-server-7.2.4-sources.jar: sql/postgres/deleteTenantObjects.sql <==
DELETE FROM arch_contract_data WHERE tenantid = ${tenantid};
DELETE FROM contract_data WHERE tenantid = ${tenantid};
DELETE FROM actormember WHERE tenantid = ${tenantid};
DELETE FROM actor WHERE tenantid = ${tenantid};
DELETE FROM processcategorymapping WHERE tenantid = ${tenantid};
DELETE FROM category WHERE tenantid = ${tenantid};
DELETE FROM arch_process_comment WHERE tenantid = ${tenantid};
DELETE FROM process_comment WHERE tenantid = ${tenantid};
DELETE FROM process_definition WHERE tenantid = ${tenantid};
DELETE FROM arch_document_mapping WHERE tenantid = ${tenantid};
DELETE FROM document WHERE tenantid = ${tenantid};
DELETE FROM document_mapping WHERE tenantid = ${tenantid};
DELETE FROM arch_flownode_instance WHERE tenantid = ${tenantid};
DELETE FROM arch_process_instance WHERE tenantid = ${tenantid};
DELETE FROM arch_connector_instance  WHERE tenantid = ${tenantid};
DELETE FROM arch_multi_biz_data WHERE tenantid = ${tenantid};
DELETE FROM arch_ref_biz_data_inst WHERE tenantid = ${tenantid};
DELETE FROM multi_biz_data WHERE tenantid = ${tenantid};
DELETE FROM ref_biz_data_inst WHERE tenantid = ${tenantid};
DELETE FROM connector_instance WHERE tenantid = ${tenantid};
DELETE FROM message_instance WHERE tenantid = ${tenantid};
DELETE FROM pending_mapping WHERE tenantid = ${tenantid};
DELETE FROM event_trigger_instance WHERE tenantid = ${tenantid};
DELETE FROM waiting_event WHERE tenantid = ${tenantid};
DELETE FROM process_instance WHERE tenantid = ${tenantid};
DELETE FROM flownode_instance WHERE tenantid = ${tenantid};
DELETE FROM report WHERE tenantid = ${tenantid};
DELETE FROM processsupervisor WHERE tenantid = ${tenantid};
DELETE FROM business_app WHERE tenantid = ${tenantid};
DELETE FROM business_app_page WHERE tenantid = ${tenantid};
DELETE FROM business_app_menu WHERE tenantid = ${tenantid};
DELETE FROM command WHERE tenantid = ${tenantid};
DELETE FROM arch_data_instance WHERE tenantid = ${tenantid};
DELETE FROM data_instance WHERE tenantid = ${tenantid};
DELETE FROM dependencymapping WHERE tenantid = ${tenantid};
DELETE FROM dependency WHERE tenantid = ${tenantid};
DELETE FROM external_identity_mapping WHERE tenantid = ${tenantid};
DELETE FROM user_membership WHERE tenantid = ${tenantid};
DELETE FROM custom_usr_inf_val WHERE tenantid = ${tenantid};
DELETE FROM custom_usr_inf_def WHERE tenantid = ${tenantid};
DELETE FROM user_login WHERE tenantid = ${tenantid};
DELETE FROM user_ WHERE tenantid = ${tenantid};
DELETE FROM user_contactinfo WHERE tenantid = ${tenantid};
DELETE FROM role WHERE tenantid = ${tenantid};
DELETE FROM group_ WHERE tenantid = ${tenantid};
DELETE FROM queriablelog_p WHERE tenantid = ${tenantid};
DELETE FROM queriable_log WHERE tenantid = ${tenantid};
DELETE FROM page WHERE tenantid = ${tenantid};
DELETE FROM sequence WHERE tenantid = ${tenantid};
DELETE FROM profilemember WHERE tenantid = ${tenantid};
DELETE FROM profileentry WHERE tenantid = ${tenantid};
DELETE FROM profile WHERE tenantid = ${tenantid};
DELETE FROM job_log WHERE tenantid = ${tenantid};
DELETE FROM job_param WHERE tenantid = ${tenantid};
DELETE FROM job_desc WHERE tenantid = ${tenantid};
DELETE FROM theme WHERE tenantid = ${tenantid};
DELETE FROM form_mapping WHERE tenantid = ${tenantid};
DELETE FROM page_mapping WHERE tenantid = ${tenantid};
DELETE FROM process_content WHERE tenantid = ${tenantid};
DELETE FROM proc_parameter WHERE tenantid = ${tenantid};
